@@ -46,6 +46,8 @@ from core_main_app.views.common.ajax import EditTemplateVersionManagerView
 from core_main_app.views.common.views import CommonView
 from core_main_app.views.user.forms import WorkspaceForm
 
+import math
+
 if "core_curate_app" in INSTALLED_APPS:
     import core_curate_app.components.curate_data_structure.api as curate_data_structure_api
 if "core_composer_app" in INSTALLED_APPS:
@@ -255,10 +257,14 @@ class DashboardRecords(CommonView):
             ),
             "menu": self.administration,
             "administration": self.administration,
+            "share_pid_button": "core_linked_records_app" in settings.INSTALLED_APPS,
         }
+
         if self.administration:
             context.update(
-                {"username_list": get_id_username_dict(user_api.get_all_users())}
+                {
+                    "username_list": get_id_username_dict(user_api.get_all_users()),
+                }
             )
 
         modals = [
@@ -269,6 +275,24 @@ class DashboardRecords(CommonView):
 
         assets = self._get_assets()
 
+        if context["share_pid_button"]:
+            modals.append("core_linked_records_app/user/sharing/data_detail/modal.html")
+
+            assets["js"] += [
+                {
+                    "path": "core_main_app/user/js/sharing_modal.js",
+                    "is_raw": False,
+                },
+                {
+                    "path": "core_linked_records_app/user/js/sharing/common_list.js",
+                    "is_raw": False,
+                },
+                {
+                    "path": "core_linked_records_app/user/js/sharing/data_list.js",
+                    "is_raw": False,
+                },
+            ]
+
         return self.common_render(
             request, self.template, context=context, assets=assets, modals=modals
         )
@@ -408,6 +432,7 @@ class DashboardFiles(CommonView):
             "document": dashboard_constants.FUNCTIONAL_OBJECT_ENUM.FILE.value,
             "template": dashboard_constants.DASHBOARD_FILES_TEMPLATE_TABLE,
             "menu": self.administration,
+            "share_pid_button": "core_linked_records_app" in settings.INSTALLED_APPS,
         }
 
         if self.administration:
@@ -467,6 +492,24 @@ class DashboardFiles(CommonView):
             assets["css"].append("core_file_preview_app/user/css/file_preview.css")
             modals.append("core_file_preview_app/user/file_preview_modal.html")
 
+        if context["share_pid_button"]:
+            modals.append("core_linked_records_app/user/sharing/data_detail/modal.html")
+
+            assets["js"] += [
+                {
+                    "path": "core_main_app/user/js/sharing_modal.js",
+                    "is_raw": False,
+                },
+                {
+                    "path": "core_linked_records_app/user/js/sharing/common_list.js",
+                    "is_raw": False,
+                },
+                {
+                    "path": "core_linked_records_app/user/js/sharing/blob_list.js",
+                    "is_raw": False,
+                },
+            ]
+
         # Admin
         if self.administration:
             assets["js"].append(
@@ -678,7 +721,6 @@ class DashboardTemplates(CommonView):
                 "template": dashboard_constants.DASHBOARD_TEMPLATES_TEMPLATE_TABLE,
                 "menu": False,
             }
-
             modals = [
                 "core_main_app/admin/templates/list/modals/disable.html",
                 EditTemplateVersionManagerView.get_modal_html_path(),
@@ -926,7 +968,7 @@ class DashboardWorkspaceRecords(CommonView):
                 workspace, request.user
             )
         except AccessControlError as ace:
-            workspace_data = []
+            workspace_data = workspace_data_api.get_none()
 
         user_can_read = workspace_api.can_user_read_workspace(workspace, request.user)
         user_can_write = workspace_api.can_user_write_workspace(workspace, request.user)
@@ -1073,6 +1115,7 @@ class DashboardQueries(CommonView):
     """List the queries."""
 
     template = dashboard_constants.DASHBOARD_TEMPLATE
+    data_template = dashboard_constants.DASHBOARD_QUERIES_TEMPLATE_TABLE_PAGINATION
 
     def get(self, request, *args, **kwargs):
         """Method GET
@@ -1120,7 +1163,7 @@ class DashboardQueries(CommonView):
         # Paginator
         page = request.GET.get("page", 1)
         results_paginator = ResultsPaginator.get_results(
-            items_to_render, page, settings.RECORD_PER_PAGE_PAGINATION
+            items_to_render, page, settings.QUERY_PER_PAGE_PAGINATION
         )
         for result_view in ResultQueryRedirectView.__subclasses__():
             if result_view.model_name == query_subclass._class_name:
@@ -1129,6 +1172,31 @@ class DashboardQueries(CommonView):
                 query_type = result_view.object_name
                 break
 
+        # get pagination information
+        previous_page_number = (
+            results_paginator.previous_page_number()
+            if results_paginator.has_previous()
+            else None
+        )
+        next_page_number = (
+            results_paginator.next_page_number()
+            if results_paginator.has_next()
+            else None
+        )
+        results_count = items_to_render.count()
+        page_count = int(
+            math.ceil(float(results_count) / settings.QUERY_PER_PAGE_PAGINATION)
+        )
+
+        # pagination has other pages?
+        has_other_pages = results_count > settings.QUERY_PER_PAGE_PAGINATION
+
+        # pagination has previous?
+        has_previous = previous_page_number is not None
+
+        # pagination has next?
+        has_next = next_page_number is not None and next_page_number <= page_count
+
         try:
             detailed_query = self._get_detailed_queries(results_paginator)
         except:
@@ -1139,17 +1207,28 @@ class DashboardQueries(CommonView):
             "number_total": items_to_render.count(),
             "user_data": detailed_query,
             "document": dashboard_constants.FUNCTIONAL_OBJECT_ENUM.QUERY.value,
-            "template": dashboard_constants.DASHBOARD_QUERIES_TEMPLATE_TABLE,
+            "template": self.data_template,
             "type": query_type,
             "url_path": url_path,
             "tab": tab_selected,
             "tabs": tabs,
             "menu": self.administration,
+            "pagination": {
+                "number": int(page),
+                "paginator": {"num_pages": page_count},
+                "has_other_pages": has_other_pages,
+                "previous_page_number": previous_page_number,
+                "next_page_number": next_page_number,
+                "has_previous": has_previous,
+                "has_next": has_next,
+            },
         }
 
         if self.administration:
             context.update(
-                {"action_form": ActionForm([("1", "Delete selected queries")])}
+                {
+                    "action_form": ActionForm([("1", "Delete selected queries")]),
+                }
             )
 
         modals = [
@@ -1198,9 +1277,21 @@ class DashboardQueries(CommonView):
                     "path": "core_dashboard_common_app/user/js/list/modals/edit_persistent_query.js",
                     "is_raw": False,
                 },
+                {
+                    "path": "core_main_app/libs/highlight/11.0.0/js/highlight.min.js",
+                    "is_raw": False,
+                },
+                {
+                    "path": "core_main_app/libs/highlight/11.0.0/js/init_highlight.js",
+                    "is_raw": False,
+                },
             ],
         }
         assets["css"].append("core_dashboard_app/common/css/my_dashboard_tabs.css")
+        assets["css"].append("core_dashboard_common_app/common/css/content_query.css")
+        assets["css"].append(
+            "core_main_app/libs/highlight/11.0.0/css/atom-one-light.css"
+        )
 
         # Admin
         if self.administration:
